# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from formant.protos.agent.v1 import agent_pb2 as protos_dot_agent_dot_v1_dot_agent__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from formant.protos.model.v1 import intervention_pb2 as protos_dot_model_dot_v1_dot_intervention__pb2
from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2


class AgentStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamData = channel.stream_unary(
                '/v1.agent.Agent/StreamData',
                request_serializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.StreamDataResponse.FromString,
                )
        self.PostData = channel.unary_unary(
                '/v1.agent.Agent/PostData',
                request_serializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataResponse.FromString,
                )
        self.PostDataMulti = channel.unary_unary(
                '/v1.agent.Agent/PostDataMulti',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiResponse.FromString,
                )
        self.GetTeleopControlDataStream = channel.unary_stream(
                '/v1.agent.Agent/GetTeleopControlDataStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamResponse.FromString,
                )
        self.GetTeleopHeartbeatStream = channel.unary_stream(
                '/v1.agent.Agent/GetTeleopHeartbeatStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamResponse.FromString,
                )
        self.GetTelemetryListenerStream = channel.unary_stream(
                '/v1.agent.Agent/GetTelemetryListenerStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamResponse.FromString,
                )
        self.GetCustomDataChannelMessageStream = channel.unary_stream(
                '/v1.agent.Agent/GetCustomDataChannelMessageStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamResponse.FromString,
                )
        self.CreateEvent = channel.unary_unary(
                '/v1.agent.Agent/CreateEvent',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventResponse.FromString,
                )
        self.CreateInterventionRequest = channel.unary_unary(
                '/v1.agent.Agent/CreateInterventionRequest',
                request_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
                response_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
                )
        self.GetInterventionRequest = channel.unary_unary(
                '/v1.agent.Agent/GetInterventionRequest',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionRequestRequest.SerializeToString,
                response_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
                )
        self.GetInterventionResponse = channel.unary_unary(
                '/v1.agent.Agent/GetInterventionResponse',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionResponseRequest.SerializeToString,
                response_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionResponse.FromString,
                )
        self.GetStreamsConfiguration = channel.unary_unary(
                '/v1.agent.Agent/GetStreamsConfiguration',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationResponse.FromString,
                )
        self.GetApplicationConfiguration = channel.unary_unary(
                '/v1.agent.Agent/GetApplicationConfiguration',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationResponse.FromString,
                )
        self.GetConfigBlobData = channel.unary_unary(
                '/v1.agent.Agent/GetConfigBlobData',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataResponse.FromString,
                )
        self.GetAgentConfiguration = channel.unary_unary(
                '/v1.agent.Agent/GetAgentConfiguration',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationResponse.FromString,
                )
        self.Health = channel.unary_unary(
                '/v1.agent.Agent/Health',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthResponse.FromString,
                )
        self.GetCommandRequest = channel.unary_unary(
                '/v1.agent.Agent/GetCommandRequest',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestResponse.FromString,
                )
        self.GetCommandRequestStream = channel.unary_stream(
                '/v1.agent.Agent/GetCommandRequestStream',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamResponse.FromString,
                )
        self.SendCommandResponse = channel.unary_unary(
                '/v1.agent.Agent/SendCommandResponse',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseResponse.FromString,
                )
        self.PostTransformFrame = channel.unary_unary(
                '/v1.agent.Agent/PostTransformFrame',
                request_serializer=protos_dot_model_dot_v1_dot_math__pb2.TransformFrame.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostTransformFrameResponse.FromString,
                )
        self.SetBaseFrameID = channel.unary_unary(
                '/v1.agent.Agent/SetBaseFrameID',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDResponse.FromString,
                )
        self.ClearTransformTree = channel.unary_unary(
                '/v1.agent.Agent/ClearTransformTree',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeResponse.FromString,
                )
        self.GetTeleopInfo = channel.unary_unary(
                '/v1.agent.Agent/GetTeleopInfo',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoResponse.FromString,
                )
        self.PostLanRtcOffer = channel.unary_unary(
                '/v1.agent.Agent/PostLanRtcOffer',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferResponse.FromString,
                )
        self.SendOnCustomDataChannel = channel.unary_unary(
                '/v1.agent.Agent/SendOnCustomDataChannel',
                request_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelRequest.SerializeToString,
                response_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelResponse.FromString,
                )


class AgentServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StreamData(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostDataMulti(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTeleopControlDataStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTeleopHeartbeatStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTelemetryListenerStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomDataChannelMessageStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInterventionRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInterventionRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInterventionResponse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStreamsConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApplicationConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigBlobData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAgentConfiguration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Health(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommandRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommandRequestStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendCommandResponse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostTransformFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBaseFrameID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearTransformTree(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTeleopInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostLanRtcOffer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendOnCustomDataChannel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamData': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamData,
                    request_deserializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.StreamDataResponse.SerializeToString,
            ),
            'PostData': grpc.unary_unary_rpc_method_handler(
                    servicer.PostData,
                    request_deserializer=protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataResponse.SerializeToString,
            ),
            'PostDataMulti': grpc.unary_unary_rpc_method_handler(
                    servicer.PostDataMulti,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiResponse.SerializeToString,
            ),
            'GetTeleopControlDataStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTeleopControlDataStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamResponse.SerializeToString,
            ),
            'GetTeleopHeartbeatStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTeleopHeartbeatStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamResponse.SerializeToString,
            ),
            'GetTelemetryListenerStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetTelemetryListenerStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamResponse.SerializeToString,
            ),
            'GetCustomDataChannelMessageStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCustomDataChannelMessageStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamResponse.SerializeToString,
            ),
            'CreateEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEvent,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventResponse.SerializeToString,
            ),
            'CreateInterventionRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInterventionRequest,
                    request_deserializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
                    response_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
            ),
            'GetInterventionRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInterventionRequest,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionRequestRequest.FromString,
                    response_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
            ),
            'GetInterventionResponse': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInterventionResponse,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionResponseRequest.FromString,
                    response_serializer=protos_dot_model_dot_v1_dot_intervention__pb2.InterventionResponse.SerializeToString,
            ),
            'GetStreamsConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStreamsConfiguration,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationResponse.SerializeToString,
            ),
            'GetApplicationConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApplicationConfiguration,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationResponse.SerializeToString,
            ),
            'GetConfigBlobData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigBlobData,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataResponse.SerializeToString,
            ),
            'GetAgentConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAgentConfiguration,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationResponse.SerializeToString,
            ),
            'Health': grpc.unary_unary_rpc_method_handler(
                    servicer.Health,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.HealthResponse.SerializeToString,
            ),
            'GetCommandRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCommandRequest,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestResponse.SerializeToString,
            ),
            'GetCommandRequestStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetCommandRequestStream,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamResponse.SerializeToString,
            ),
            'SendCommandResponse': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCommandResponse,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseResponse.SerializeToString,
            ),
            'PostTransformFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.PostTransformFrame,
                    request_deserializer=protos_dot_model_dot_v1_dot_math__pb2.TransformFrame.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostTransformFrameResponse.SerializeToString,
            ),
            'SetBaseFrameID': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBaseFrameID,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDResponse.SerializeToString,
            ),
            'ClearTransformTree': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearTransformTree,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeResponse.SerializeToString,
            ),
            'GetTeleopInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTeleopInfo,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoResponse.SerializeToString,
            ),
            'PostLanRtcOffer': grpc.unary_unary_rpc_method_handler(
                    servicer.PostLanRtcOffer,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferResponse.SerializeToString,
            ),
            'SendOnCustomDataChannel': grpc.unary_unary_rpc_method_handler(
                    servicer.SendOnCustomDataChannel,
                    request_deserializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelRequest.FromString,
                    response_serializer=protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.agent.Agent', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Agent(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StreamData(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/v1.agent.Agent/StreamData',
            protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.StreamDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/PostData',
            protos_dot_model_dot_v1_dot_datapoint__pb2.Datapoint.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostDataMulti(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/PostDataMulti',
            protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostDataMultiResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTeleopControlDataStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v1.agent.Agent/GetTeleopControlDataStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopControlDataStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTeleopHeartbeatStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v1.agent.Agent/GetTeleopHeartbeatStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopHeartbeatStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTelemetryListenerStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v1.agent.Agent/GetTelemetryListenerStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTelemetryListenerStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomDataChannelMessageStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v1.agent.Agent/GetCustomDataChannelMessageStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCustomDataChannelMessageStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/CreateEvent',
            protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.CreateEventResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInterventionRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/CreateInterventionRequest',
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.SerializeToString,
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInterventionRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetInterventionRequest',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionRequestRequest.SerializeToString,
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInterventionResponse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetInterventionResponse',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetInterventionResponseRequest.SerializeToString,
            protos_dot_model_dot_v1_dot_intervention__pb2.InterventionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStreamsConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetStreamsConfiguration',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetStreamsConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApplicationConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetApplicationConfiguration',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetApplicationConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConfigBlobData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetConfigBlobData',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetConfigBlobDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAgentConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetAgentConfiguration',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetAgentConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Health(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/Health',
            protos_dot_agent_dot_v1_dot_agent__pb2.HealthRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.HealthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommandRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetCommandRequest',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommandRequestStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v1.agent.Agent/GetCommandRequestStream',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetCommandRequestStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendCommandResponse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/SendCommandResponse',
            protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.SendCommandResponseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostTransformFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/PostTransformFrame',
            protos_dot_model_dot_v1_dot_math__pb2.TransformFrame.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostTransformFrameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetBaseFrameID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/SetBaseFrameID',
            protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.SetBaseFrameIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearTransformTree(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/ClearTransformTree',
            protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.ClearTransformTreeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTeleopInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/GetTeleopInfo',
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.GetTeleopInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostLanRtcOffer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/PostLanRtcOffer',
            protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.PostLanRtcOfferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendOnCustomDataChannel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.agent.Agent/SendOnCustomDataChannel',
            protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelRequest.SerializeToString,
            protos_dot_agent_dot_v1_dot_agent__pb2.SendOnCustomDataChannelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
